@@ -43,7 +43,7 @@ Scale must be one of nine different scales (or their equivalent codes):
 	month  |  mo   | 1-12  or  jan, feb, mar, apr, may, jun, jul,
 	       |       |           aug, sep, oct, nov, dec
 	week   |  wk   | 1-6
-	yday   |  yd   | 1-366
+	yday   |  yd   | 1-365
 	mday   |  md   | 1-31
 	wday   |  wd   | 1-7   or  su, mo, tu, we, th, fr, sa
 	hour   |  hr   | 0-23  or  12am 1am-11am 12noon 12pm 1pm-11pm
@@ -160,23 +160,10 @@ half-hour the rest of the week, use the period
 
 =head1 VERSION
 
-1.23
+1.21
 
 =head1 HISTORY
 
-        Version 1.23
-        ------------
-                - Bug fixes:
-                    - Validate min and max for right side of hour ranges (e.g.
-                      hr { 20-25 } now correctly returns -1)
-                    - Range for yd is now 1 to 366
-                    - Years are no longer considered to be 365 days long for
-                      calculating a 4-digit year.
-
-        Version 1.23
-        ------------
-                - Fixed tests
-
         Version 1.21
         ------------
                 - Bug fix: Stopped using $' and $`.
@@ -203,9 +190,7 @@ half-hour the rest of the week, use the period
 
 =head1 AUTHOR
 
-Patrick Ryan <perl@pryan.org> wrote it.
-
-Paul Boyd <pboyd@cpan.org> fixed a few bugs.
+Patrick Ryan <pgryan@geocities.com>
 
 =head1 COPYRIGHT
 
@@ -213,6 +198,16 @@ Copyright (c) 1997 Patrick Ryan.  All rights reserved.  This Perl module
 uses the conditions given by Perl.  This module may only be distributed
 and or modified under the conditions given by Perl.
 
+=head1 DATE
+
+January 16th, 2011
+
+=head1 SOURCE
+
+This distribution can be found at
+
+	http://www.perl.com/CPAN/modules/by-module/Time/
+
 =cut
 
 package Time::Period;
@@ -222,7 +217,7 @@ require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(inPeriod);
 
-$VERSION = "1.23";
+$VERSION = "1.21";
 
 sub inPeriod {
 
@@ -395,7 +390,7 @@ sub getTimeVars {
   # The assumption for the ranges from localtime are
   #   Year      ($yr)  = 0-99
   #   Month     ($mo)  = 0-11
-  #   Year Day  ($yd)  = 0-365
+  #   Year Day  ($yd)  = 0-364
   #   Month Day ($md)  = 1-31
   #   Week Day  ($wd)  = 0-6
   #   Hour      ($hr)  = 0-23
@@ -403,7 +398,7 @@ sub getTimeVars {
   #   Second    ($sec) = 0-59
 
   # Calculate the full year (yyyy).
-  $yr += 1900;
+  $yr = int($time / 31536000) + 1970;
 
   # Figure out which week $time is in ($wk) so that $wk goes from 0-5.
 
@@ -574,8 +569,8 @@ sub yd {
     return -1 if ( ($v1 =~ /\D/) || ($v2 =~ /\D/) );
     $v1--;
     $v2--;
-    return -1 if ( ($v1 < 0) || ($v1 > 365) );
-    return -1 if ( ($v2 < 0) || ($v2 > 365) );
+    return -1 if ( ($v1 < 0) || ($v1 > 364) );
+    return -1 if ( ($v2 < 0) || ($v2 > 364) );
     if ($v1 > $v2) {
       return 1 if ( ($v1 <= $yd) || ($v2 >= $yd) );
     } else {
@@ -583,7 +578,7 @@ sub yd {
     }
   } else {
     $range--;
-    return -1 if (($range =~ /\D/) || ($range < 0) || ($range > 365));
+    return -1 if (($range =~ /\D/) || ($range < 0) || ($range > 364));
     return 1 if ($range == $yd);
   }
 
@@ -721,7 +716,6 @@ sub hr {
       $v2 = $1;
     }
     return -1 if ( ($v1 =~ /\D/) || ($v1 < 0) || ($v1 > 23) );
-    return -1 if ( ($v2 =~ /\D/) || ($v2 < 0) || ($v2 > 23) );
 
     if ($v1 > $v2) {
       return 1 if ( ($v1 <= $hr) || ($v2 >= $hr) );
